/**
 * @description Wrap表单配置信息
 */
export default function (group) {
  let appType = sessionStorage.getItem('appType')
  let fields = [{field: '', label: '空'}]

  if (appType === 'mob') {
    group.fields.forEach(f => {
      if (f.field && ['select', 'text', 'number'].includes(f.type) && f.hidden !== 'true' && f.readonly !== 'true') {
        fields.push(f)
      }
    })
  } else {
    group.fields.forEach(f => {
      if (f.field && ['select', 'link', 'text', 'number'].includes(f.type) && f.hidden !== 'true' && f.readonly !== 'true') {
        fields.push(f)
      }
    })
  }

  const groupForm = [
    {
      type: 'text',
      field: 'title',
      label: '标题',
      initval: group.setting.title || '',
      required: true
    },
    {
      type: 'text',
      field: 'status',
      label: '状态值',
      initval: group.setting.status || '',
      tooltip: '用于表单加载时的状态控制。',
      required: false,
      forbid: !group.prevButton
    },
    {
      type: 'select',
      field: 'focus',
      label: '焦点',
      initval: group.setting.focus || '',
      required: false,
      options: fields
    },
    {
      type: 'radio',
      field: 'cache',
      label: '选项查询',
      initval: group.setting.cache || 'true',
      tooltip: '需要通过数据源查询的选项，是否使用缓存。',
      required: false,
      options: [
        {value: 'true', label: '缓存'},
        {value: 'false', label: '实时'},
      ]
    },
    {
      type: 'radio',
      field: 'align',
      label: '表单排列',
      initval: group.setting.align || 'left_right',
      required: false,
      options: [
        {value: 'left_right', label: '左右'},
        {value: 'up_down', label: '上下'},
      ],
      forbid: appType === 'mob'
    },
    {
      type: 'radio',
      field: 'verticalSpace',
      label: '竖向间隙',
      initval: group.setting.verticalSpace || 'normal',
      tooltip: '正常间隙会预留出报错信息的位置，防止表单位置发生变化。',
      required: false,
      options: [
        {value: 'normal', label: '正常'},
        {value: 'middle', label: '中'},
        {value: 'small', label: '小'},
      ],
      forbid: appType === 'mob'
    },
    {
      type: 'radio',
      field: 'prevEnable',
      label: '上一步',
      initval: group.prevButton ? group.prevButton.enable || 'false' : 'false',
      tooltip: '第一组不显示。',
      required: false,
      options: [
        {value: 'true', label: '显示'},
        {value: 'false', label: '隐藏'},
      ],
      forbid: !group.prevButton
    },
    {
      type: 'radio',
      field: 'subEnable',
      label: '提交',
      initval: group.subButton.enable || 'true',
      required: false,
      options: [
        {value: 'true', label: '显示'},
        {value: 'false', label: '隐藏'},
      ]
    },
    {
      type: 'radio',
      field: 'nextEnable',
      label: '跳过',
      initval: group.nextButton ? group.nextButton.enable || 'false' : 'false',
      tooltip: '最后一组不显示。',
      required: false,
      options: [
        {value: 'true', label: '显示'},
        {value: 'false', label: '隐藏'},
      ],
      forbid: !group.nextButton
    },
  ]

  return groupForm
} 